#
# spec file for package logwatch
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           logwatch
Version:        7.13
Release:        1.1
Summary:        Tool to analyze and report on system logs
License:        MIT
Group:          System/Monitoring
URL:            https://sourceforge.net/projects/logwatch/
Source0:        https://sourceforge.net/projects/logwatch/files/%{name}-%{version}/%{name}-%{version}.tar.gz
Source1:        %{name}-rpmlintrc
Source2:        Logwatch_Dmeventd_Setup_Files.tar.xz
Source3:        ChangeLog
Patch0:         logwatch-firewall.patch
Patch2:         logwatch-timestamp_in_var.patch
Patch3:         harden_logwatch.service.patch
Patch4:         harden_logwatch_dmeventd.service.patch
BuildRequires:  xz
Requires:       grep
Requires:       mailx
Requires:       perl
Requires:       perl-Date-Manip
Requires:       perl-HTML-Parser
Requires:       sh-utils
Requires:       textutils
BuildArch:      noarch
# The main reason for using systemd timers for logwatch is on distros which
# use timers for logrotate, to keep logwatch running before logrotate, as it
# does where both use cron.daily.  We don't need to use systemd timers on all
# distros with systemd, just those with logrotate.timer, which for SUSE is
# SLE 12 SP3/Leap 42.3 and newer (including 15.x).
%{?systemd_requires}
%if 0%{?suse_version}
BuildRequires:  systemd-rpm-macros
%else
BuildRequires:  systemd
%endif

%description
Logwatch is a customizable, pluggable log-monitoring system. It will go
through system logs for a given period of time and make a report for the
desired areas at the desired detail level.

%prep
%setup -q -a 2
chmod u+w Logwatch_Setup_Files/*
%patch -P 0
%patch -P 2
cp %{SOURCE3} .
# fix package doc dir in man page
sed -i -e 's,%{_datadir}/doc/logwatch-\*,%{_defaultdocdir}/logwatch,' logwatch.8
%patch -P 3 -p1
%patch -P 4 -p1

%build

%install
install -m 0755 -d %{buildroot}%{_var}/cache/logwatch
install -m 0755 -d %{buildroot}%{_sysconfdir}/logwatch/scripts
install -m 0755 -d %{buildroot}%{_sysconfdir}/logwatch/conf
install -m 0755 -d %{buildroot}%{_sysconfdir}/logwatch/conf/logfiles
install -m 0755 -d %{buildroot}%{_sysconfdir}/logwatch/conf/services
install -m 0755 -d %{buildroot}%{_datadir}/logwatch/default.conf/logfiles
install -m 0755 -d %{buildroot}%{_datadir}/logwatch/default.conf/services
install -m 0755 -d %{buildroot}%{_datadir}/logwatch/default.conf/html
install -m 0755 -d %{buildroot}%{_datadir}/logwatch/dist.conf/logfiles
install -m 0755 -d %{buildroot}%{_datadir}/logwatch/dist.conf/services
install -m 0755 -d %{buildroot}%{_datadir}/logwatch/scripts/services
install -m 0755 -d %{buildroot}%{_datadir}/logwatch/scripts/shared
install -m 0755 -d %{buildroot}%{_datadir}/logwatch/lib
install -m 0755 -d %{buildroot}%{_localstatedir}/lib/logwatch
install -m 0755 scripts/logwatch.pl %{buildroot}%{_datadir}/logwatch/scripts/logwatch.pl
for i in scripts/logfiles/* ; do
   if [ $(ls $i | wc -l) -ne 0 ] ; then
      install -m 0755 -d %{buildroot}%{_datadir}/logwatch/$i
      install -m 0755 $i/* %{buildroot}%{_datadir}/logwatch/$i
   fi
done
install -m 0755 scripts/services/* %{buildroot}%{_datadir}/logwatch/scripts/services
install -m 0755 Logwatch_Setup_Files/dmeventd %{buildroot}%{_datadir}/logwatch/scripts/services
install -m 0755 scripts/shared/* %{buildroot}%{_datadir}/logwatch/scripts/shared
install -m 0755 lib/* %{buildroot}%{_datadir}/logwatch/lib
install -m 0644 conf/*.conf %{buildroot}%{_datadir}/logwatch/default.conf
install -m 0644 conf/logfiles/* %{buildroot}%{_datadir}/logwatch/default.conf/logfiles
# these apache log paths are not included in default.conf:
cat > %{buildroot}%{_datadir}/logwatch/dist.conf/logfiles/http.conf << EOF
Archive = apache2/access_log-*.xz
EOF
cat > %{buildroot}%{_datadir}/logwatch/dist.conf/logfiles/http-error.conf << EOF
LogFile = apache2/error_log
Archive = apache2/error_log-*
EOF
install -m 0644 conf/services/* %{buildroot}%{_datadir}/logwatch/default.conf/services
install -m 0644 Logwatch_Setup_Files/dmeventd.conf %{buildroot}%{_datadir}/logwatch/dist.conf/services
install -m 0644 conf/html/* %{buildroot}%{_datadir}/logwatch/default.conf/html
install -m 0755 -d %{buildroot}%{_mandir}/man8
install -m 0644 logwatch.8 %{buildroot}%{_mandir}/man8
install -m 0755 -d %{buildroot}%{_mandir}/man5
install -m 0644 logwatch.conf.5 %{buildroot}%{_mandir}/man5
# replace man page alias files with symlinks
for f in {ignore,override}.conf.5; do
    ln -s logwatch.conf.5 %{buildroot}%{_mandir}/man5/$f
done
rm -f   %{buildroot}%{_sysconfdir}/cron.daily/logwatch \
   %{buildroot}%{_sbindir}/logwatch

install -D -m 644 scheduler/logwatch.service %{buildroot}%{_unitdir}/logwatch.service
install -D -m 644 scheduler/logwatch.timer %{buildroot}%{_unitdir}/logwatch.timer
install -D -m 644 scheduler/systemd.conf %{buildroot}%{_datadir}/logwatch/default.conf/systemd.conf
install -D -m 644 Logwatch_Setup_Files/logwatch_dmeventd.service %{buildroot}%{_unitdir}/logwatch_dmeventd.service
install -D -m 644 Logwatch_Setup_Files/logwatch_dmeventd.timer %{buildroot}%{_unitdir}/logwatch_dmeventd.timer
install -m 0755 -d %{buildroot}%{_sbindir}
ln -sf %{_sbindir}/service %{buildroot}%{_sbindir}/rclogwatch
ln -sf %{_sbindir}/service %{buildroot}%{_sbindir}/rclogwatch_dmeventd
ln -s %{_datadir}/logwatch/scripts/logwatch.pl %{buildroot}%{_sbindir}/logwatch
echo "###### REGULAR EXPRESSIONS IN THIS FILE WILL BE TRIMMED FROM REPORT OUTPUT #####" > %{buildroot}%{_sysconfdir}/logwatch/conf/ignore.conf
echo "# Local configuration options go here (defaults are in %{_datadir}/logwatch/default.conf/logwatch.conf)" > %{buildroot}%{_sysconfdir}/logwatch/conf/logwatch.conf
echo "# Local configuration options go here (defaults are in %{_datadir}/logwatch/default.conf/systemd.conf)" > %{buildroot}%{_sysconfdir}/logwatch/conf/systemd.conf
echo "# Configuration overrides for specific logfiles/services may be placed here." > %{buildroot}%{_sysconfdir}/logwatch/conf/override.conf
#

%pre
%service_add_pre %{name}.service %{name}.timer logwatch_dmeventd.service logwatch_dmeventd.timer

%post
%service_add_post %{name}.service %{name}.timer logwatch_dmeventd.service logwatch_dmeventd.timer
# migration: may need to activate the timer, if enabled but not yet started?

%preun
%service_del_preun %{name}.service %{name}.timer logwatch_dmeventd.service logwatch_dmeventd.timer

%postun
%service_del_postun %{name}.service %{name}.timer logwatch_dmeventd.service logwatch_dmeventd.timer

%files
%doc README HOWTO-Customize-LogWatch ChangeLog
%dir %{_var}/cache/logwatch
%dir %{_sysconfdir}/logwatch
%dir %{_sysconfdir}/logwatch/scripts
%dir %{_sysconfdir}/logwatch/conf
%dir %{_sysconfdir}/logwatch/conf/logfiles
%dir %{_sysconfdir}/logwatch/conf/services
%dir %{_datadir}/logwatch
%dir %{_datadir}/logwatch/default.conf
%dir %{_datadir}/logwatch/default.conf/services
%dir %{_datadir}/logwatch/default.conf/logfiles
%dir %{_datadir}/logwatch/default.conf/html
%dir %{_datadir}/logwatch/dist.conf
%dir %{_datadir}/logwatch/dist.conf/services
%dir %{_datadir}/logwatch/dist.conf/logfiles
%dir %{_datadir}/logwatch/scripts
%dir %{_datadir}/logwatch/scripts/logfiles
%dir %{_datadir}/logwatch/scripts/services
%dir %{_datadir}/logwatch/scripts/shared
%dir %{_datadir}/logwatch/scripts/logfiles/*
%dir %{_datadir}/logwatch/lib
%dir %{_localstatedir}/lib/logwatch
%{_datadir}/logwatch/scripts/logwatch.pl
%{_sbindir}/logwatch
%{_datadir}/logwatch/scripts/shared/*
%{_datadir}/logwatch/scripts/services/*
%{_datadir}/logwatch/scripts/logfiles/*/*
%{_datadir}/logwatch/lib/Logwatch.pm
%{_datadir}/logwatch/default.conf/*.conf
%{_datadir}/logwatch/default.conf/services/*.conf
%{_datadir}/logwatch/default.conf/logfiles/*.conf
%{_datadir}/logwatch/default.conf/html/*.html
%{_datadir}/logwatch/dist.conf/services/*.conf
%{_datadir}/logwatch/dist.conf/logfiles/*.conf
%{_unitdir}/logwatch.service
%{_unitdir}/logwatch.timer
%{_unitdir}/logwatch_dmeventd.service
%{_unitdir}/logwatch_dmeventd.timer
%{_sbindir}/rclogwatch
%{_sbindir}/rclogwatch_dmeventd
%{_mandir}/man8/logwatch.8%{?ext_man}
%{_mandir}/man5/*.conf.5%{?ext_man}
%config(noreplace) %{_sysconfdir}/logwatch/conf/*.conf

%changelog
* Wed Jul 23 2025 ecsos <ecsos@opensuse.org>
- Update to 7.13
  See /usr/share/doc/packages/logwatch/ChangeLog for details
* Thu Oct 31 2024 ecsos <ecsos@opensuse.org>
- Update to 7.11
  See /usr/share/doc/packages/logwatch/ChangeLog for details
* Fri Mar  1 2024 pgajdos@suse.com
- Use %%patch -P N instead of deprecated %%patchN.
* Sat Sep 23 2023 Johannes Kastl <kastl@b1-systems.de>
- Add Requires for perl-HTML-Parser, see boo#1215630
* Wed Aug 16 2023 ecsos <ecsos@opensuse.org>
- Update to 7.9
  See /usr/share/doc/packages/logwatch/ChangeLog for details
- Add missing systemd.conf for scheduling.
* Wed Jul 12 2023 Johannes Segitz <jsegitz@suse.com>
- Make home directories read only instead of hiding them completely
  (bsc#1212692)
* Thu Jun 22 2023 Dirk Müller <dmueller@suse.com>
- update to 7.8:
  * no upstream changelog available
- drop logwatch-7.5.5-egrep.patch (upstream)
* Sat Sep 24 2022 Dirk Müller <dmueller@suse.com>
- update to 7.7:
  * various warning fixes
* Thu Sep 22 2022 Andreas Stieger <andreas.stieger@gmx.de>
- fix warnings due to GNU grep 3.8 deprecation boo#1203665
  add logwatch-7.5.5-egrep.patch
* Tue Oct  5 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Added patch(es):
  * harden_logwatch.service.patch
  * harden_logwatch_dmeventd.service.patch
* Fri Jul 16 2021 Andrew Daugherity <adaugherity@tamu.edu>
- Update URL (logwatch.org is no more).
- Minor ChangeLog cleanup.
* Wed Jan 27 2021 Christian Vögl <christian.voegl@suse.com>
- Update to 7.5.5.
  See /usr/share/doc/packages/logwatch/ChangeLog for details
* Wed Jul 22 2020 Christian Vögl <christian.voegl@suse.com>
- Update to 7.5.3.
  See /usr/share/doc/packages/logwatch/ChangeLog for details.
* Mon Jan 20 2020 Christian Vögl <cvoegl@suse.de>
- Remove cron support:
  * Add logwatch_dmeventd timer and unit file to
    Logwatch_Dmeventd_Setup_Files.tar.xz
    The new logwatch_dmeventd timer has to be started manually,
    in contrast to the previous cronjob
  * Removed logwatch-dmeventd-reduce_frequency.patch:
    No longer needed with systemd timers
* Tue Aug 27 2019 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summary. Generalize description.
* Tue Aug 20 2019 kukuk@suse.de
- BuildRequire cron as this contains now the cron directories
* Thu Aug  8 2019 Christian Vögl <christian.voegl@suse.com>
- Only use cron if systemd timers are not installed
* Thu Jul 25 2019 Andrew Daugherity <adaugherity@tamu.edu>
- Combine changelog files.
- Update to 7.5.2.
  See /usr/share/doc/packages/logwatch/ChangeLog for details.
* Wed Feb 13 2019 adaugherity@tamu.edu
- Update to 7.5.1.
  Many changes, see the various changelog files under
  /usr/share/doc/packages/logwatch.  No upstream changelog is provided,
  so these were created from the git log.
  * Notable changes include support for xz archive files and for
    running as a systemd timer.
- Drop logwatch-conf-5.patch -- a similar fix was made upstream.
- dos2unix is not needed for build -- courier script was fixed in 2008.
- Configure apache log paths not included by default conf (e.g. xz log
  archives).
- Move dmeventd conf to dist.conf (default.conf is for upstream) and
  make its cron.d file config(noreplace).
* Mon Oct 22 2018 adaugherity@tamu.edu
- fix documentation path in logwatch(8) man page
- install missing logwatch.conf(5) man page
  => logwatch-conf-5.patch
* Thu Jan 18 2018 dimstar@opensuse.org
- Remove duplicate BuildArch: noarch.
* Fri Jan 20 2017 bwiedemann@suse.com
- Drop USEDFORBUILD as it breaks build-compare
  when any of the 113 build dependencies changed
* Mon May  2 2016 pth@suse.de
- Update to 7.4,3 (fate#320641)
  List of changes in 7.4.2 is long so please so please see
  logwatch-7.4.2.changelog in /usr/src/packages/logwatch.
  Changes for 7.4.3:
  [kernel] Fix default Ignore_messages value to not match anything
- Removed logwatch-http.patch as the fix is in upstream code.
* Tue Sep  1 2015 manfred.h@gmx.net
- Add new patch to deal with Perl's pickyness regarding curly
  brackets in patterns (logwatch-http.patch).
* Fri Feb 20 2015 p.drouand@gmail.com
- Update to version 7.4.1
  * No changelog available
- Remove logwatch-parse_rsyslog_timestamps.patch; merged on upstream
  release
- Spec file clean up
  * Remove obsolete macros
  * Remove redundant %%clean section
* Mon Dec  2 2013 tbehrens@suse.com
- Update logwatch-firewall.patch to prevent 'Removing duplicate
  Archive file' warning.
* Mon Jun 17 2013 pth@suse.de
- Add logwatch-parse_rsyslog_timestamps.patch that makes logwatch
  understand the default timestamp format of newer rsyslog versions
  (bnc#818842).
* Tue Dec 18 2012 robert.munteanu@gmail.com
- Added logwatch-dmeventd-reduce_frequency.patch to reduce false
  positives from dmeventd when a long logwatch run is in progress
* Mon Oct 17 2011 pth@suse.de
- Update to 7.4.0 which is the official release with the fix for
  CVE-2011-1018.
- Fix cron.d file to state the user to run dmeventd as (bnc#724164).
- Fix file list for 7.4.0.
* Sun Feb 27 2011 jslaby@suse.de
- Fix CVE-2011-1018 patch (missing parenthesis)
* Fri Feb 25 2011 pth@suse.de
- Add patch to fix the handling of special characters in log files
  (CVE-2011-1018, bnc#674984).
- Make files in Logwatch_Dmeventd_Setup_Files tarball 644 and
  repack with bzip2.
* Tue Feb  1 2011 pth@suse.de
- Fix Requires for SLE10.
* Mon May 10 2010 pth@novell.com
- Require perl-Date-Manip (bnc#603959).
* Tue Dec  1 2009 pth@suse.de
- --print was set by default and in that case redirection to file
  never happened (bnc#450413).
* Sun Aug 30 2009 coolo@novell.com
- use %%patch0 for Patch0
* Mon Jan 19 2009 pth@suse.de
- Log timestamp of dmeventd in /var/lib/logwatch not
  /etc/logwatch/scripts/services.
- Add /var/lib/logwatch to file list (bnc#467272)
* Fri Jan 16 2009 pth@suse.de
- Fix a few typos in logwatch.conf
* Tue Jan 13 2009 pth@suse.de
- Call sendmail with full path (bnc#465127).
* Mon Oct 13 2008 pth@suse.de
- Add files to let logwatch capture DM events (fate#304214, bnc#434254)
* Tue Apr  8 2008 crrodriguez@suse.de
- logwatch does not watch anything without cron
* Mon Nov 12 2007 pth@suse.de
- Patch iptables.conf to also monitor the SUSE firewall logs (#334167)
- Update to 7.3.6:
  - Fixed bug with --mailto not working with printing now enabled by default
  - Fixed problem with the Samba filter
  - New services bfd, zz-runtime, evtsystem, evtsecurity, and evtapplication.
  - Default behavior is now to print output which means you will see the
    report if you run it from the command-line and when run from cron it will
    be emailed to you by the cron daemon.  You can change this through config
    or command-line options.
  - Substantial Postfix improvements and other minor changes and fixes
  - Numerous other filter improvements
  - Added dpkg, pix, denyhosts, and php services
* Thu Nov 23 2006 mge@suse.de
- check into autobuild
- update to 7.3.1
- FATE #300526
